@@ -4,12 +4,16 @@
 import pandas as pd
 import numpy as np
 
+from importlib.resources import files
+data_text = files('DSBA_Final.data').joinpath('Final_Project_Raw_Data.csv')
+
 def load_data():
-    df = pd.read_csv('data/Final_Project_Raw_Data.csv')
+    df = pd.read_csv(data_text)
 
     return df
 
 def count_ripper(data_frame, column_name, brewery_name):
+
     individual_brewery = data_frame.loc[(data_frame[column_name] == brewery_name)]
 
     individual_brewery_na_dropped = individual_brewery.raw_visit_counts.dropna()
